==> mail-1.0.tar.gz: mail-1.0/source/javax/mail/Header.java <==
/*
 * Header.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail;

/**
 * The Header class stores a name/value pair to represent headers.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public class Header
{

  /**
   * The name.
   */
  protected String name;

  /**
   * The value.
   */
  protected String value;

  /**
   * Construct a Header object.
   * @param name name of the header
   * @param value value of the header
   */
  public Header(String name, String value)
  {
    this.name = name;
    this.value = value;
  }

  /**
   * Returns the name of this header.
   */
  public String getName()
  {
    return name;
  }

  /**
   * Returns the value of this header.
   */
  public String getValue()
  {
    return value;
  }

}

==> mail-1.1.tar.gz: mail-1.1/source/javax/mail/Header.java <==
/*
 * Header.java
 * Copyright (C) 2002 The Free Software Foundation
 * 
 * This file is part of GNU JavaMail, a library.
 * 
 * GNU JavaMail is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * GNU JavaMail is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * As a special exception, if you link this library with other files to
 * produce an executable, this library does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * This exception does not however invalidate any other reasons why the
 * executable file might be covered by the GNU General Public License.
 */

package javax.mail;

/**
 * A header is a name/value pair containing metadata about a message's
 * content and/or routing information.
 *
 * @author <a href="mailto:dog@gnu.org">Chris Burdess</a>
 * @version 1.3
 */
public class Header
{

  /**
   * The name.
   */
  String name;

  /**
   * The value.
   */
  String value;

  /**
   * Construct a header.
   * @param name name of the header
   * @param value value of the header
   */
  public Header(String name, String value)
  {
    this.name = name;
    this.value = value;
  }

  /**
   * Returns the name of this header.
   */
  public String getName()
  {
    return name;
  }

  /**
   * Returns the value of this header.
   */
  public String getValue()
  {
    return value;
  }

}
